@@ -9,7 +9,7 @@ set -e
 #export LC_ALL=C
 
 latest_automake() {
-	for v in "-1.10" "-1.9" "-1.8" "-1.7" "-1.6" "" ; do
+	for v in "-1.11" "-1.10" "-1.9" "-1.8" "-1.7" "-1.6" "" ; do
 		if which "automake$v" >/dev/null ; then
 			echo "$v"
 			return
