@@ -7,7 +7,7 @@
  *      Implementation of the Large Objects interface
  *   Allows access to large objects directly, or though I/O streams
  *
- * Copyright (c) 2003-2008, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2003-2013, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -30,6 +30,8 @@
 
 #include "pqxx/largeobject"
 
+#include "pqxx/internal/gates/connection-largeobject.hxx"
+
 using namespace PGSTD;
 using namespace pqxx::internal;
 
@@ -135,6 +137,13 @@ void pqxx::largeobject::remove(dbtransaction &T) const
 }
 
 
+pqxx::internal::pq::PGconn *pqxx::largeobject::RawConnection(
+	const dbtransaction &T)
+{
+  return gate::connection_largeobject(T.conn()).RawConnection();
+}
+
+
 string pqxx::largeobject::Reason(int err) const
 {
   if (err == ENOMEM) return "Out of memory";
@@ -212,15 +221,16 @@ pqxx::largeobjectaccess::cseek(off_type dest, seekdir dir) throw ()
 pqxx::largeobjectaccess::pos_type
 pqxx::largeobjectaccess::cwrite(const char Buf[], size_type Len) throw ()
 {
-  return
-    PGSTD::max(lo_write(RawConnection(),m_fd,const_cast<char *>(Buf), Len), -1);
+  const pos_type bytes_written = lo_write(
+	RawConnection(), m_fd, const_cast<char *>(Buf), size_t(Len));
+  return PGSTD::max(bytes_written, -1L);
 }
 
 
 pqxx::largeobjectaccess::pos_type
 pqxx::largeobjectaccess::cread(char Buf[], size_type Bytes) throw ()
 {
-  return PGSTD::max(lo_read(RawConnection(), m_fd, Buf, Bytes), -1);
+  return PGSTD::max(lo_read(RawConnection(), m_fd, Buf, size_t(Bytes)), -1);
 }
 
 
