@@ -54,7 +54,7 @@ class FailedInsert : public transactor<robusttransaction<serializable> >
   static string LastReason;
 public:
   FailedInsert(string Table) :
-    transactor<argument_type>("FailedInsert"),
+    transactor<argument_type>("FailedInsert018"),
     m_Table(Table)
   {
   }
@@ -82,8 +82,9 @@ public:
 string FailedInsert::LastReason;
 
 
-void test_018(connection_base &C, transaction_base &T)
+void test_018(transaction_base &T)
 {
+  connection_base &C(T.conn());
   T.abort();
 
   const string Table = "pqxxevents";
