@@ -12,8 +12,9 @@ namespace
 int BoringYear = 1977;
 
 
-void test_039(connection_base &C, transaction_base &T1)
+void test_039(transaction_base &T1)
 {
+  connection_base &C(T1.conn());
   const string Table = "pqxxevents";
 
 
