@@ -128,8 +128,9 @@ private:
 };
 
 
-void test_050(connection_base &C, transaction_base &orgT)
+void test_050(transaction_base &orgT)
 {
+  connection_base &C(orgT.conn());
   orgT.abort();
 
   largeobject Obj;
