@@ -58,8 +58,9 @@ private:
 };
 
 
-void test_054(connection_base &C, transaction_base &orgT)
+void test_054(transaction_base &orgT)
 {
+  connection_base &C(orgT.conn());
   orgT.abort();
 
   largeobject Obj;
