@@ -60,8 +60,9 @@ private:
 };
 
 
-void test_055(connection_base &C, transaction_base &orgT)
+void test_055(transaction_base &orgT)
 {
+  connection_base &C(orgT.conn());
   orgT.abort();
 
   largeobject Obj;
