@@ -65,8 +65,9 @@ public:
 };
 
 
-void test_079(connection_base &C, transaction_base &orgT)
+void test_079(transaction_base &orgT)
 {
+  connection_base &C(orgT.conn());
   orgT.abort();
 
   const string NotifName = "mylistener";
