@@ -9,8 +9,9 @@ using namespace pqxx;
 // Test inhibition of connection reactivation
 namespace
 {
-void test_086(connection_base &C, transaction_base &N1)
+void test_086(transaction_base &N1)
 {
+  connection_base &C(N1.conn());
   const string Query = "SELECT * from pg_tables";
 
   cout << "Some datum: " << N1.exec(Query)[0][0] << endl;
