@@ -92,8 +92,9 @@ static void set_fdbit(fd_set &s, int b)
 }
 
 
-void test_087(connection_base &C, transaction_base &orgT)
+void test_087(transaction_base &orgT)
 {
+  connection_base &C(orgT.conn());
   orgT.abort();
 
   const string NotifName = "my notification";
